// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
// 
// This program is free software; you can redistribute it and/or 
// modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation; either 
// version 2 of the License, or (at your option) any later 
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
///****************************************************************************
//** $Id: qt/qwerty.cpp   3.3.4   edited May 27 2003 $
//**
//** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
//**
//** This file is part of an example program for Qt.  This example
//** program may be used, distributed and modified without limitation.
//**
//*****************************************************************************/

#include "qwerty.h"
#include <qmessagebox.h>



LineDialog::LineDialog(): QDialog(0, "Enter line number", true) {
	QVBoxLayout *vly = new QVBoxLayout(this);
	vly->setAutoAdd(true);

	QHBox *hbox = new QHBox(this);
	label_ = new QLabel("Line: ", hbox);
	text_ = new QLineEdit(hbox);
	button_ = new QPushButton("Ok", hbox);

	connect(button_, SIGNAL(clicked()), SLOT(accept()));
}

int LineDialog::getLine() {
	int retval;

	if (text_->text().isEmpty() == true)
		retval = -1;
	else {
		QString str = text_->text();
		bool ok;
		retval = str.toInt(&ok);
		if (!ok || retval <= 0) {
			retval = -1;
			QMessageBox::warning(0,"Error", "Not a valid line number");
		}
	}
	return retval;
}

BookmarkDialog::BookmarkDialog(): QDialog(0, "Enter bookmark number", true) {
	QVBoxLayout *vly = new QVBoxLayout(this);
	vly->setAutoAdd(true);

	QHBox *hbox = new QHBox(this);
	label_ = new QLabel("Bookmark: ", hbox);
	text_ = new QLineEdit(hbox);
	button_ = new QPushButton("Ok", hbox);

	connect(button_, SIGNAL(clicked()), SLOT(accept()));
}

int BookmarkDialog::getBookmark() {
	int retval;

	if (text_->text().isEmpty() == true)
		retval = -1;
	else {
		QString str = text_->text();
		bool ok;
		retval = str.toInt(&ok);
		if (!ok || retval < 0 || retval >= Editor::MAXBOOKMARKS) {
			retval = -1;
			QMessageBox::warning(0,"Error", "Not a valid bookmark number");
		}
	}
	return retval;
}

SearchDialog::SearchDialog(): QDialog(0, "Enter search word", true) {
	QVBoxLayout *vly = new QVBoxLayout(this);
	vly->setAutoAdd(true);

	QHBox *hbox = new QHBox(this);
	label_ = new QLabel("Word: ", hbox);
	text_ = new QLineEdit(hbox);
	button_ = new QPushButton("Ok", hbox);

	connect(button_, SIGNAL(clicked()), SLOT(accept()));
	QAccel *a = new QAccel(this);		  // create accels for myWindow
	a->connectItem(a->insertItem(ALT+Key_A), this, SLOT(unicode_a()));
	a->connectItem(a->insertItem(SHIFT+ALT+Key_A), this, SLOT(unicode_A()));
	a->connectItem(a->insertItem(ALT+Key_S), this, SLOT(unicode_s()));
	a->connectItem(a->insertItem(SHIFT+ALT+Key_S), this, SLOT(unicode_S()));
	a->connectItem(a->insertItem(ALT+Key_Q), this, SLOT(unicode_q()));
	a->connectItem(a->insertItem(SHIFT+ALT+Key_Q), this, SLOT(unicode_Q()));
	a->connectItem(a->insertItem(ALT+Key_T), this, SLOT(unicode_t()));
	a->connectItem(a->insertItem(SHIFT+ALT+Key_T), this, SLOT(unicode_T()));
	a->connectItem(a->insertItem(ALT+Key_I), this, SLOT(unicode_i()));
	a->connectItem(a->insertItem(SHIFT+ALT+Key_I), this, SLOT(unicode_I()));
}

QString SearchDialog::getWord() {
	QString retval;

	if (text_->text().isEmpty() == true)
		retval = "";
	else {
		retval = text_->text();
	}
	return retval;
}

void SearchDialog::unicode_a() {
	QString str = QString::fromUtf8("ă");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_A() {
	QString str = QString::fromUtf8("Ă");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_s() {
	QString str = QString::fromUtf8("ş");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_S() {
	QString str = QString::fromUtf8("Ş");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_q() {
	QString str = QString::fromUtf8("â");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_Q() {
	QString str = QString::fromUtf8("Â");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_t() {
	QString str = QString::fromUtf8("ţ");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_T() {
	QString str = QString::fromUtf8("Ţ");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_i() {
	QString str = QString::fromUtf8("î");
	text_->insert(str);
	text_->cursorForward(false);
}

void SearchDialog::unicode_I() {
	QString str = QString::fromUtf8("Î");
	text_->insert(str);
	text_->cursorForward(false);
}




WwwDialog::WwwDialog(): QDialog(0, "Enter www location", true) {
	QVBoxLayout *vly = new QVBoxLayout(this);
	vly->setAutoAdd(true);

	QHBox *hbox = new QHBox(this);
	label_ = new QLabel("url: ", hbox);
	text_ = new QLineEdit(hbox);
	button_ = new QPushButton("Ok", hbox);

	connect(button_, SIGNAL(clicked()), SLOT(accept()));
}

QString WwwDialog::getWord() {
	QString retval;

	if (text_->text().isEmpty() == true)
		retval = "";
	else {
		retval = text_->text();
	}
	return retval;
}

StatusDialog::StatusDialog(QFont &fnt, char *msg): QDialog(0, "File status", true) {
	ASSERT(msg != 0);
	QVBoxLayout *vly = new QVBoxLayout(this);
	vly->setAutoAdd(true);

	QHBox *hbox = new QHBox(this);

	QString qstr = QString::fromUtf8(msg);

	label_ = new QLabel(qstr, hbox);
	label_->setFont(fnt);
	button_ = new QPushButton("Ok", hbox);

	connect(button_, SIGNAL(clicked()), SLOT(accept()));
}


