// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
// 
// This program is free software; you can redistribute it and/or 
// modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation; either 
// version 2 of the License, or (at your option) any later 
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
///****************************************************************************
//** $Id: qt/main.cpp   3.3.4   edited May 27 2003 $
//**
//** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
//**
//** This file is part of an example program for Qt.  This example
//** program may be used, distributed and modified without limitation.
//**
//*****************************************************************************/

#include <qapplication.h>
#include "qwerty.h"
#include "spell.h"
#include "global.h"

static void usage() {
	printf("NAME\n");
	printf("   rospell - editor si corector/speller UTF-8 pentru limba romana.\n");
	printf("\n");
	printf("SYNOPSYS\n");
	printf("   rospell [options] filename\n");
	printf("\n");
	printf("DESCRIPTION\n");
	printf("   rospell este structurat ca un editor de text similar cu gedit. Pentru a\n");
	printf("   porni spelling-ul din pozitia curenta a cursorului, apasati meniul\n");
	printf("   Start Spelling. Folositi Ignore pentru a sari peste un cuvant,\n");
	printf("   sau Add pentru a adauga cuvantul in dictionarul user local\n");
	printf("   aflat in directorul /home/username/.rospell.\n");
	printf("\n");
	printf("   rospell suporta seturile de caractere UTF-8, ISO8859-2/16 si CP1250.\n");
	printf("   Daca formatul nu este specificat folosind --iso8859-2/16 sau --cp1250,\n");
	printf("   fisierele sunt presupuse a fi in format UTF-8.\n");
	printf("\n");
	printf("   rospell foloseste tasta ALT din partea drepta a barei de spatiu\n");
	printf("   pentru introducerea caracterelor diacritice romanesti dupa cum urmeaza:\n");
	printf("\n");
	printf("       ALT-a, ALT-s, ALT-q, ALT-t, ALT-i\n");
	printf("\n");
	printf("OPTIONS\n");
	printf("   -v: versiunea instalata.\n");
	printf("\n");
	printf("   -h, -?, --help: acest ecran de help.\n");
	printf("\n");
	printf("   --iso8859-2: fisierele sunt in format ISO8859-2.\n");
	printf("\n");
	printf("   --iso8859-16: fisierele sunt in format ISO8859-16.\n");
	printf("\n");
	printf("   --cp1250: fisierele sunt in format CP1250 (Windows).\n");
	printf("\n");
	printf("   (urmatoarele optiuni sunt valabile numai pentru formatul UTF-8)\n");
	printf("\n");
	printf("   -m: adauga toate cuvintele la dictionarul master\n");
	printf("\n");
	printf("   -u: adauga toate cuvintele la dictionarul user\n");
	printf("\n");
	printf("   -p: tipareste cuvintele noi\n");
	printf("\n");
	printf("EXAMPLE\n");
	printf("   $ rospell file*.txt\n");
	printf("   - porneste speller-ul in format default UTF-8\n");
	printf("\n");
	printf("   $ rospell --iso8859-2 file*.txt\n");
	printf("   - porneste speller-ul in format ISO8859-2\n");
	printf("\n");
	printf("   $ rospell -p file*.txt\n");
	printf("   - genereaza o lista de cuvinte necunoscute de catre speller din\n");
	printf("   fisierele specificate\n");
	printf("\n");
	printf("AUTHOR\n");
	printf("   http://rospell.sourceforge.net\n");
}

static Editor *start(const char *fname, Editor::FILE_FORMAT format) {
	LOG("start");
	Editor *e = new Editor;

	if (fname == 0) {
		LOG("start with no file");
		e->setFname(0);
		e->setFormat(format);
	} else {
		e->setFname(fname);
		e->load(fname, format);
	}

	bool isSmall =  qApp->desktop()->size().width() < 450
				 || qApp->desktop()->size().height() < 450;

	if (isSmall) {
		e->showMaximized();
	} else {
		e->resize(Global::instance()->xsize, Global::instance()->ysize);
		LOG("main editor sizes %d %d", Global::instance()->xsize, Global::instance()->ysize);
		e->show();
	}

	return e;
}

int main( int argc, char **argv )
{
	Action *aptr = 0;
	int start_arg = 1;

	Editor::FILE_FORMAT format = Editor::FILE_UTF8;

	if (argc > 1) {
		if (strcmp(argv[1], "--iso8859-2") == 0) {
			LOG("main: option -iso8859-2");
			format = Editor::FILE_ISO8859_2;
			start_arg = 2;
		}

		if (strcmp(argv[1], "--iso8859-16") == 0) {
			LOG("main: option -iso8859-16");
			format = Editor::FILE_ISO8859_16;
			start_arg = 2;
		}

		if (strcmp(argv[1], "--cp1250") == 0) {
			LOG("main: option -cp1250");
			format = Editor::FILE_CP1250;
			start_arg = 2;
		}

		if (strcmp(argv[1], "-m") == 0) {
			aptr = new ActionAddAllMaster();
			Global::instance()->addallmaster = true;
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-u") == 0) {
			aptr = new ActionAddAllUser();
			Global::instance()->addalluser = true;
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-p") == 0) {
			aptr = new ActionDumpAll();
			Global::instance()->dumpall = true;
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-h") == 0 ||
				 strcmp(argv[1], "-?") == 0 ||
				 strcmp(argv[1], "--help") == 0) {
			usage();
			return 0;
		} else if (strcmp(argv[1], "-v") == 0) {
			printf("rospell versiunea %s\n", VERSION);
			return 0;
		}
	}

	Dictionaries *pdict = new Dictionaries(!Global::instance()->addallmaster); 
	if (!Global::instance()->addallmaster) {
		readHomeDir(pdict);
	}
	if (aptr != 0) {
		for (int i = start_arg; i < argc; i++) {
			char *fstr = UTILS::read_file_malloc(argv[i]);
			if (fstr == 0)
				continue;
			fprintf(stderr, "Process file %s\n", argv[i]);
			char *ptmp = spell(pdict, aptr, fstr);
			delete[] ptmp;
		}
	}
	if (Global::instance()->addallmaster) {
		pdict->saveMaster();
	}

	delete aptr;   
	delete pdict;  
	Stats::instance()->print();
	Stats::instance(true);
	if (Global::instance()->addallmaster ||
	    Global::instance()->addalluser ||
	    Global::instance()->dumpall) {
		return 0;
	}

	Global::instance()->getCfg();    
	QApplication a( argc, argv);

	int i;
	Editor *e = 0; 
	if (argc == start_arg)
		e = start(0, format);
	else {
		for (i= start_arg; i<argc; i++) {
			e = start(argv[i], format);
		}
	}
	if (e == 0) // just in case!
		return 1;
	a.connect( &a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()) );

	int retval = a.exec();
	Global::instance()->saveCfg();
	Global::instance(true);
	Stats::instance(true);    
	return retval;

//    return a.exec();
}

