// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
// 
// This program is free software; you can redistribute it and/or 
// modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation; either 
// version 2 of the License, or (at your option) any later 
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************
//** $Id: qt/qwerty.h   3.3.4   edited May 27 2003 $
//**
//** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
//**
//** This file is part of an example program for Qt.  This example
//** program may be used, distributed and modified without limitation.
//**
//*****************************************************************************/

#ifndef QWERTY_H
#define QWERTY_H

#include <qwidget.h>
#include <qmenubar.h>
#include <qmultilineedit.h>
#include <qprinter.h> 
#include <qdialog.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qfont.h>
#include <qhbox.h>
#include <qvbox.h>
#include <qlayout.h>
#include <qaccel.h>
#include <qsyntaxhighlighter.h>

#include <stdio.h>
#include <string.h>
#include "../../config.h"


// forward declaration
class Dictionaries;

class StatusDialog: public QDialog {
public:
	StatusDialog(QFont &fnt, char *msg);
private:
	QLabel *label_;
	QPushButton *button_;    
};



class WwwDialog: public QDialog {
public:
	WwwDialog();
	QString getWord();
private:
	QLabel *label_;
	QLineEdit *text_;
	QPushButton *button_;    
};

class SearchDialog: public QDialog {
	Q_OBJECT

	public:
	SearchDialog();
	QString getWord();
private slots:
	void unicode_a();
	void unicode_A();
	void unicode_s();
	void unicode_S();
	void unicode_q();
	void unicode_Q();
	void unicode_t();
	void unicode_T();
	void unicode_i();
	void unicode_I();
private:
	QLabel *label_;
	QLineEdit *text_;
	QPushButton *button_;    
};

class LineDialog: public QDialog {
public:
	LineDialog();
	int getLine();
private:
	QLabel *label_;
	QLineEdit *text_;
	QPushButton *button_;    
};

class BookmarkDialog: public QDialog {
public:
	BookmarkDialog();
	int getBookmark();
private:
	QLabel *label_;
	QLineEdit *text_;
	QPushButton *button_;    
};



class SyntaxHighlighter : public QSyntaxHighlighter {
public:
	SyntaxHighlighter(QTextEdit *textEdit);
	virtual ~SyntaxHighlighter(void);

	int highlightParagraph(const QString &text, int endStateOfLastPara);
};



class Editor : public QWidget {
	Q_OBJECT

	public:
	typedef enum {
		FILE_UTF8 = 0,
		FILE_ISO8859_2,
		FILE_ISO8859_16,
		FILE_CP1250
	} FILE_FORMAT;

public:
	Editor( QWidget *parent=0, const char *name="qwerty" );
	~Editor();
	void load( const QString& fileName, FILE_FORMAT format);
	void setFormat(FILE_FORMAT format);
	void setFname(QString fname, bool modified = false);
	QString getFname();
	

public slots:
	void newDoc();
	void load();
	void openWwwLocation();
	bool save();
	bool saveAs();
	void print();
	void font();
	void spellAdvance();
	void spellIgnore();
	void spellAdd();
	void spellName();
	void undo();
	void cut();
	void copy();
	void paste();
	void e_delete();
	void search();
	void searchAgain();
	void gotoLine();
	void setBookmark();
	void gotoBookmark();
	void status();
	void uppercase();
	void lowercase();
	void dexonline();
protected:
	void resizeEvent( QResizeEvent * );
	void closeEvent( QCloseEvent * );

private slots:
	void textChanged();
	void clicked(int para, int pos);
	void unicode_a();
	void unicode_A();
	void unicode_s();
	void unicode_S();
	void unicode_q();
	void unicode_Q();
	void unicode_t();
	void unicode_T();
	void unicode_i();
	void unicode_I();
	void replaceWord1();
	void replaceWord2();
	void replaceWord3();
	void replaceWord4();
	void replaceWord5();

private:
	char *format2str();
	void msgScreen(char *str, int mstime = 0);
	bool saveCommon( const QString& fileName);
	FILE_FORMAT detectWwwFormat(const char *str);
	QString toUtf8(const char *str, FILE_FORMAT format);
	void advanceStartWord();
	QString advanceEndWord();
	bool skeepXML();
	
	void cleanMWords();
	// lookalike words entry point
	void doLookalike(char *active_word);
	// first i to â lookalike
	bool lookalike1(char *active_word, char *dest);
	// the second i to â lookalike
	bool lookalike2(char *active_word, char *dest);
	// first î to â lookalike
	bool lookalike3(char *active_word, char *dest);
	// flip char lookalike
	bool lookalike4(char *active_word, char *dest);
	// insert lookalike in empty storage word
	void insertLookalike(char *str);
	
	char *stripDexonline(char *str);

	QAccel *a_;
	QPopupMenu *file_;
	QPopupMenu *edit_;
	QPopupMenu *tools_;
	SyntaxHighlighter *syntax_;
	int msgid_; // id for message in menubar 
	QMenuBar       *m_;
	QMenuBar       *mwords_;
	int mw1_;	//id for the first word in mwords_ menu bar
	int mw2_;	//id for the second word in mwords_ menu bar
	int mw3_;	//id for the third word in mwords_ menu bar
	int mw4_;	//id for the fourth word in mwords_ menu bar
	int mw5_;	//id for the fifth word in mwords_ menu bar
	char word1_[100];
	char word2_[100];
	char word3_[100];
	char word4_[100];
	char word5_[100];

	QMultiLineEdit *e_;
#ifndef QT_NO_PRINTER
	QPrinter        printer_;
#endif
	bool changed_;
	Dictionaries *pdict_;
	QString search_;
	FILE_FORMAT format_;

	QString line_;
	int x_;
	int y_;
	int xword_;
	int yword_;

	// bookmarks
public:
	static const int MAXBOOKMARKS = 10;
private:
	int xbook_[MAXBOOKMARKS];
	int ybook_[MAXBOOKMARKS];
};

#endif // QWERTY_H


